import pytest

"""
This is a framework of the test for the quote api endpoint
"""


def test_can_call_quote_api_without_params():
    assert True == True


def test_can_call_quote_api_with_params():
    assert True == True


def test_can_call_quote_api_with_filters():
    assert True == True


def test_can_call_quote_api_with_params_and_filters():
    assert True == True



class AbstractBaseClass(object):
    """
    This is an abstract class for implementing abstract classes
    """

    def __init__(self, client_sdk):
        self.client_sdk = client_sdk

    def get(self, params=None, filters={}):
        """
        params contains things like id , subquery, etc
        filters contain filters for pagination e.g limit, page and offset
        """
        return self.client_sdk.request(
            method_type="get", params=params, api_type=self.api_type, filters=filters
        )



import pytest

"""
This is a framework of the test for the client class
"""


def test_can_initialize_client_with_apikey():
    assert True == True


def test_cannot_initialize_client_without_api_key():
    assert True == True


def test_can_initialize_client_without_version():
    assert True == True
